package Qt::Gui::QTextTableFormat;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextTableFormat
# file     : QtGui/qtextformat.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QTextFrameFormat/;
#our @ISA = qw/Qt::Gui::QTextFrameFormat/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QTextTableFormat

=head1 PUBLIC METHODS

=over

=item   QTextTableFormat()

=item  QFlags<Qt::AlignmentFlag> alignment()

=item  qreal cellPadding()

=item  qreal cellSpacing()

=item  void clearColumnWidthConstraints()

=item  int columns()

=item  int headerRowCount()

=item  bool isValid()

=item  void setAlignment(QFlags<Qt::AlignmentFlag> alignment)

=item  void setCellPadding(qreal padding)

=item  void setCellSpacing(qreal spacing)

=item  void setColumns(int columns)

=item  void setHeaderRowCount(int count)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
